@@ -1,6 +1,7 @@
 import typer
 from .registry import DockerRegistryClient
 from .view.info import print_image_info
+from .view.info import print_tags_info
 
 app = typer.Typer()
 
@@ -23,6 +24,16 @@ def pull(name: str = typer.Argument(..., help="The name of the user to greet")):
     typer.echo("Not implemented yet")
 
 
+@app.command()
+def tags(image_name: str = typer.Argument(..., help="The name of the image")):
+    """
+    List all the tags available for an image
+    """
+    drc = DockerRegistryClient()
+    tags_info = drc.GetTags(image_name)
+    print_tags_info(tags_info)
+
+
 def main():
     app()
 
